@@ -5,33 +5,53 @@ import { connect } from 'react-redux'
 import { ConnectedRouter } from 'connected-react-router'
 import { renderRoutes } from 'react-router-config'
 
-import { Grid } from 'patternfly-react'
 import LoadingData from './components/LoadingData'
 import OvirtApiCheckFailed from './components/OvirtApiCheckFailed'
-import TokenExpired from './components/TokenExpired'
+import SessionActivityTracker from './components/SessionActivityTracker'
 import VmsPageHeader from './components/VmsPageHeader'
 import ToastNotifications from './components/ToastNotifications'
 
 import getRoutes from './routes'
 import AppConfiguration from './config'
-import { fixedStrings } from './branding'
+import { fixedStrings, resourcesUrls } from './branding'
 import { msg } from '_/intl'
 
 /**
  * Login (token) to Engine is missing.
  */
-const NoLogin = () => {
+const NoLogin = ({ logoutWasManual = false }) => {
   return (
-    <div className='blank-slate-pf'>
-      <div className='blank-slate-pf-icon'>
-        <span className='pficon pficon pficon-user' />
+    <div>
+      <nav className='navbar obrand_mastheadBackground obrand_topBorder navbar-pf-vertical'>
+        <div className='navbar-header'>
+          <a href='/' className='navbar-brand obrand_headerLogoLink' id='pageheader-logo'>
+            <img className='obrand_mastheadLogo' src={resourcesUrls.clearGif} />
+          </a>
+        </div>
+      </nav>
+      <div className='container text-center'>
+        <h1 className='bolder'>
+          { logoutWasManual ? msg.logoutMessageManual() : msg.logoutMessageAutomatic() }
+        </h1>
+
+        <div style={{ margin: '25px 0' }}>
+          { window.DEVELOPMENT ? msg.logoutDeveloperMessage() : msg.logoutRedirected() }
+        </div>
+
+        <div>
+          <a href={AppConfiguration.applicationURL}>{msg.login()}</a>
+        </div>
       </div>
-      <h1>
-        {msg.pleaseLogInTripleDot()} <br /><a href={AppConfiguration.applicationURL}>Log in</a>
-      </h1>
     </div>
   )
 }
+NoLogin.propTypes = {
+  logoutWasManual: PropTypes.bool.isRequired,
+}
+
+function isLoginMissing (config) {
+  return !config.get('loginToken')
+}
 
 const UnsupportedBrowser = () => (
   <div className='unsupported-browser-container'>
@@ -54,20 +74,21 @@ const UnsupportedBrowser = () => (
   </div>
 )
 
+function isBrowserUnsupported () {
+  return (navigator.userAgent.indexOf('MSIE') !== -1) || (!!document.documentMode === true)
+}
+
 /**
  * Main App component. Wrap the main react-router components together with
  * the various dialogs and error messages that may be needed.
  */
 const App = ({ history, config, appReady }) => {
-  if ((navigator.userAgent.indexOf('MSIE') !== -1) || (!!document.documentMode === true)) {
+  if (isBrowserUnsupported()) {
     return <UnsupportedBrowser />
   }
-  if (!config.get('loginToken')) { // login is missing
-    return (
-      <Grid fluid>
-        <NoLogin />
-      </Grid>
-    )
+
+  if (isLoginMissing(config)) {
+    return <NoLogin logoutWasManual={config.get('logoutWasManual')} />
   }
 
   return (
@@ -75,10 +96,10 @@ const App = ({ history, config, appReady }) => {
       <div id='app-container'>
         <VmsPageHeader title={fixedStrings.BRAND_NAME + ' ' + msg.vmPortal()} />
         <OvirtApiCheckFailed />
-        <TokenExpired />
-        { appReady && renderRoutes(getRoutes()) }
         <LoadingData />
         <ToastNotifications />
+        { appReady && <SessionActivityTracker /> }
+        { appReady && renderRoutes(getRoutes()) }
       </div>
     </ConnectedRouter>
   )
@@ -93,6 +114,6 @@ App.propTypes = {
 export default connect(
   (state) => ({
     config: state.config,
-    appReady: state.config.get('isFilterChecked'), // When is the app ready to display data components?
+    appReady: !!state.config.get('appConfigured'), // When is the app ready to display data components?
   })
 )(App)
