@@ -1,11 +1,10 @@
 import { combineReducers } from 'redux'
 
 import config from './config'
-import userMessages from './userMessages'
 import vms from './vms'
+import userMessages from './userMessages'
 import icons from './icons'
 import options from './options'
-
 import templates from './templates'
 import clusters from './clusters'
 import hosts from './hosts'
@@ -15,10 +14,10 @@ import dataCenters from './dataCenters'
 import vnicProfiles from './vnicProfiles'
 import activeRequests from './activeRequests'
 import consoles from './consoles'
-import { reducer as VmDialog } from '../components/VmDialog/reducer'
+import pendingTasks from './pendingTasks'
+
 import { reducer as OptionsDialog } from '../components/OptionsDialog/reducer'
 import NewDiskDialog from '../components/NewDiskDialog/reducers'
-import pendingTasks from './pendingTasks'
 
 export default combineReducers({
   config,
@@ -28,15 +27,15 @@ export default combineReducers({
   options,
   templates,
   clusters,
-  operatingSystems,
   hosts,
+  operatingSystems,
   storageDomains,
   dataCenters,
   vnicProfiles,
-  VmDialog,
-  OptionsDialog,
-  NewDiskDialog,
-  pendingTasks,
   activeRequests,
   consoles,
+  pendingTasks,
+
+  OptionsDialog,
+  NewDiskDialog,
 })
