@@ -1,5 +1,4 @@
 import { Map } from 'immutable'
-import logger from '../logger'
 import { UPDATE_ICONS, REMOVE_ACTIVE_REQUEST, DELAYED_REMOVE_ACTIVE_REQUEST, ADD_ACTIVE_REQUEST } from '_/constants'
 
 /**
@@ -45,7 +44,7 @@ export const actionReducer = (initialState, handlers, verbose) => (state = initi
     }
 
     if (![ ADD_ACTIVE_REQUEST, REMOVE_ACTIVE_REQUEST, DELAYED_REMOVE_ACTIVE_REQUEST ].includes(action.type)) {
-      logger.log('Reducing action:', actionJson)
+      console.log('Reducing action:', actionJson)
     }
   }
 
